/*
 *  TOPPERS/JSP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Just Standard Profile Kernel
 * 
 *  Copyright (C) 2000-2004 by Embedded and Real-Time Systems Laboratory
 *                              Toyohashi Univ. of Technology, JAPAN
 *  Copyright (C) 2001-2004 by Industrial Technology Institute,
 *                              Miyagi Prefectural Government, JAPAN
 * 
 *  上記著作権者は，以下の (1)〜(4) の条件か，Free Software Foundation 
 *  によって公表されている GNU General Public License の Version 2 に記
 *  述されている条件を満たす場合に限り，本ソフトウェア（本ソフトウェア
 *  を改変したものを含む．以下同じ）を使用・複製・改変・再配布（以下，
 *  利用と呼ぶ）することを無償で許諾する．
 *  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
 *      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
 *      スコード中に含まれていること．
 *  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
 *      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
 *      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
 *      の無保証規定を掲載すること．
 *  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
 *      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
 *      と．
 *    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
 *        作権表示，この利用条件および下記の無保証規定を掲載すること．
 *    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
 *        報告すること．
 *  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
 *      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
 * 
 *  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
 *  よびTOPPERSプロジェクトは，本ソフトウェアに関して，その適用可能性も
 *  含めて，いかなる保証も行わない．また，本ソフトウェアの利用により直
 *  接的または間接的に生じたいかなる損害に関しても，その責任を負わない．
 * 
 *  @(#) $Id: user_config.h,v 1.1 2004/10/07 17:12:02 honda Exp $
 */

/*
 *	ユーザー定義の設定部
 */

#ifndef _USER_CONFIG_H_
#define _USER_CONFIG_H_

/********************************************************************
 *　PowerPCファミリ共通の設定
 *　　(1) 条件コンパイル用のフラグとして用いるマクロ
 ********************************************************************/

/*
 *  chg_ipm/get_ipm をサポートするかどうかの定義
 */
#define	SUPPORT_CHG_IPM

/*
 *  vxget_tim をサポートするかどうかの定義
 */
#define	SUPPORT_VXGET_TIM

/*
 *  プロセッサのエンディアン
 */
#define	SIL_ENDIAN	SIL_ENDIAN_BIG	/* ビッグエンディアン */

/*
 *  実行すべきタスクがない場合の割込み待ちで省電力モードに移行するか
 *　どうかの定義（フルICE向け）
 */
#define	SUPPORT_POWER_MANAGEMENT

/*
 *  レジスタの待避／復元に整数ロード／ストア・マルチプル命令を
 *　使用するどうかの定義
 */
//#define	USE_MULTIPLE_WORD_LOAD_STORE

/*
 *  例外ベクタの配置によっては、例外ベクタからtextセクションにある続き
 *  の処理に分岐する際、b命令によるPC相対分岐（前後0x07ff,ffff）では届
 *  かない場合がある。ABSOLUTE_JUMP_EXC_ENTRYマクロを定義すると絶対番
 *  地を指定して分岐する実装に切り替わり、この問題を回避できる。
 */
#define ABSOLUTE_JUMP_EXC_ENTRY


/********************************************************************
 *　PowerPCファミリ共通の設定
 *　　(2) 値を設定するマクロ
 ********************************************************************/

/*
 *  JSPカーネル動作時のメモリマップ
 *      0x0000,0000 -              データ領域(16MB)
 *                  - 0x0100,0000  タスク独立部用スタック
 *      0x1000,0000 - 0x1040,0000  コード領域(4MB)  メモリ終了
 */

/*
 *　非タスクコンテキスト用スタックの初期値
 */
#define STACKTOP    	0x01000000

/*  システムクロック [MHz] */
#define SYSTEM_CLOCK	50


/*
 *  タイマ関連の設定
 *
 */

/* タイマの割り込みレベル */
/*  MPC860Tの場合はSIUの内部レベルを表す。  */
#define INTLVL_TIMER	3

/*
 *  タイマ関連の設定
 */

/*
 *  タイムティックの定義
 */
#define	TIC_NUME	1u	/* タイムティックの周期の分子 */
#define	TIC_DENO	1u	/* タイムティックの周期の分母 */


/*
 *  シリアル関連の設定
 */

/* シリアルの割り込みレベル */
/*  MPC860Tの場合はCPMからSIUへの割込みレベルによって決定する。  */
//#define INTLVL_SERIAL

/*  ボーレート　[bps]  */
#define BAUD_RATE	9600

/*
 *  シリアルポート数の定義
 *
 *  TNUM_PORTはシリアルドライバ（serial.c）、つまり GDICレベルでサポー
 *  トしているシリアルポートの数であり、機種依存部で定義するよう共通部
 *  とのインターフェースで規定されている。
 *  一方、TNUM_SIOPはPDICレベルでサポートしているシリアルポートの数で
 *  あり、機種依存部の中でのみ用いている。
 *　
 */
#define TNUM_PORT 1	/* GDICレベルでサポートするシリアルポートの数 */
			/*  現状ではSMC1のみサポート  */

#define	TNUM_SIOP 1	/* PDICレベルでサポートするシリアルポートの数 */
			/*  現状ではSMC1のみサポート  */

#define	LOGTASK_PORTID	1  /* システムログに用いるシリアルポート番号 */
			/*  現状ではSMC1のみサポート  */


/********************************************************************
 *  オリジナルのPowerPCアーキテクチャ固有の設定項目
 *　　(1) 条件コンパイル用のフラグとして用いるマクロ
 ********************************************************************/

/*
 *  ディスパッチャで浮動小数点レジスタの待避／復元を行うか
 *　どうかの定義
 *　（MPC860Tは浮動小数点レジスタが実装されていない。）
 */
//#define	SUPPORT_FLOATING_POINT_REG

/*
 *  インプリメンテーション固有の例外0x00a00を使用する
 *　どうかの定義
 */
//#define	IMPLEMENT_EXCEPTION_00A00


/********************************************************************
 *  MPC860T固有の設定項目
 *　　(1) 条件コンパイル用のフラグとして用いるマクロ
 ********************************************************************/

/*
 *  SILを使用したときのログ機能を有効にするかどうかの定義
 */
//#define	SIL_DEBUG


/********************************************************************
 *  MPC860T固有の設定項目
 *　　(2) 値を設定するマクロ
 ********************************************************************/

/*
 *  CPMからSIUへの割込み要求レベル
 *  　シリアル割込みのレベル定義を兼ねている。
 */
#define CPM_INT_LEVEL	4



#endif /* _USER_CONFIG_H_ */
